#[unsafe(no_mangle)]pub unsafe extern "C" fn _dispatch_exception(
trap_frame: &TrapFrame,
code: usize,
)Expand description
It calls the corresponding exception handler depending on the exception source code.
Safety
This function must be called only from the crate::start_trap_rust function.
Do NOT call this function directly.